@@ -87,8 +87,9 @@ class EssClient(AbstractClient):
 
 
     def CreateDocument(self, request):
-        """创建电子文档
+        """创建签署流程电子文档
         适用场景：见创建签署流程接口。
+
         注：该接口需要给对应的流程指定一个模板id，并且填充该模板中需要补充的信息。是“发起流程”接口的前置接口。
 
         :param request: Request instance for CreateDocument.
@@ -120,7 +121,7 @@ class EssClient(AbstractClient):
     def CreateFlow(self, request):
         """创建签署流程
         适用场景：在标准制式的合同场景中，可通过提前预制好模板文件，每次调用模板文件的id，补充合同内容信息及签署信息生成电子合同。
-        注：改接口是通过模板生成合同流程的前置接口，先创建一个不包含签署文件的流程。配合“创建电子文档”接口和“发起流程”接口使用。
+        注：该接口是通过模板生成合同流程的前置接口，先创建一个不包含签署文件的流程。配合“创建电子文档”接口和“发起流程”接口使用。
 
         :param request: Request instance for CreateFlow.
         :type request: :class:`tencentcloud.ess.v20201111.models.CreateFlowRequest`
@@ -151,7 +152,7 @@ class EssClient(AbstractClient):
     def CreateFlowByFiles(self, request):
         """此接口（CreateFlowByFiles）用来通过上传后的pdf资源编号来创建待签署的合同流程。
         适用场景1：适用非制式的合同文件签署。一般开发者自己有完整的签署文件，可以通过该接口传入完整的PDF文件及流程信息生成待签署的合同流程。
-        适用场景2：可通过改接口传入制式合同文件，同时在指定位置添加签署控件。可以起到接口创建临时模板的效果。如果是标准的制式文件，建议使用模板功能生成模板ID进行合同流程的生成。
+        适用场景2：可通过该接口传入制式合同文件，同时在指定位置添加签署控件。可以起到接口创建临时模板的效果。如果是标准的制式文件，建议使用模板功能生成模板ID进行合同流程的生成。
         注意事项：该接口需要依赖“多文件上传”接口生成pdf资源编号（FileIds）进行使用。
 
         :param request: Request instance for CreateFlowByFiles.
